summaryrefslogtreecommitdiff
path: root/posix/fnmatch.h
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>1999-07-15 11:45:51 +0000
committerUlrich Drepper <drepper@redhat.com>1999-07-15 11:45:51 +0000
commitc5ccd92f4cafac5c3655f01897a91ef901c26e02 (patch)
tree381f7a8334773aa4a28c8264147d5c06e5be1a79 /posix/fnmatch.h
parent0050ad5f64b2f4b3732e59eaa070a954c2335824 (diff)
Update.
1999-07-15 Ulrich Drepper <drepper@cygnus.com> * posix/fnmatch.h: Use __name instead of __string in prototype to allow use outside glibc.
Diffstat (limited to 'posix/fnmatch.h')
-rw-r--r--posix/fnmatch.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/posix/fnmatch.h b/posix/fnmatch.h
index eeaee7fb8c..cc3ec37940 100644
--- a/posix/fnmatch.h
+++ b/posix/fnmatch.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 1991, 92, 93, 96, 97, 98 Free Software Foundation, Inc.
+/* Copyright (C) 1991, 92, 93, 96, 97, 98, 99 Free Software Foundation, Inc.
This file is part of the GNU C Library.
The GNU C Library is free software; you can redistribute it and/or
@@ -72,9 +72,9 @@ extern "C" {
# define FNM_NOSYS (-1)
#endif
/* Match STRING against the filename pattern PATTERN,
returning zero if it matches, FNM_NOMATCH if not. */
-extern int fnmatch __P ((__const char *__pattern, __const char *__string,
+extern int fnmatch __P ((__const char *__pattern, __const char *__name,
int __flags));
#ifdef __cplusplus
@@ -72,9 +72,9 @@ extern "C" {
# define FNM_NOSYS (-1)
#endif
-/* Match STRING against the filename pattern PATTERN,
+/* Match NAME against the filename pattern PATTERN,
returning zero if it matches, FNM_NOMATCH if not. */